package sdanderson.androidcharts.LineChart;

import android.content.Context;
import android.content.res.Resources;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.TextView;

import java.text.DecimalFormat;
import java.util.List;

import sdanderson.androidcharts.Common.Coordinate;
import sdanderson.androidcharts.Common.NumberUtilities;
import sdanderson.androidcharts.R;

/**
 * Created by Shane Anderson on 10/3/2015.
 *
 */
class MultipleDataPointsAdapter extends BaseAdapter {
    private List<Coordinate<Float, Float>> mCoordinates;
    private List<String> mLineLabels;
    private List<Integer> mLineColors;
    private String mXAxisLabel;
    private String mYAxisLabel;
    private boolean mUseNumberAbbreviationSuffixXValue = false;
    private boolean mUseNumberAbbreviationSuffixYValue = false;
    private DecimalFormat mDecimalFormatX = new DecimalFormat("#");
    private DecimalFormat mDecimalFormatY = new DecimalFormat("#");
    private String mNumberSuffixes = "kmbt";
    private Integer mNumberGroupSplit = 3;
    private static LayoutInflater mInflater = null;

    public MultipleDataPointsAdapter(Context pContext, List<Coordinate<Float, Float>> pCoordinates,
                                     List<String> pLabels, List<Integer> pColors,
                                     String pXAxisLabel, String pYAxisLabel,
                                     Boolean pUseNumberAbbreviationSuffixXValue,
                                     Boolean pUseNumberAbbreviationSuffixYValue,
                                     DecimalFormat pDecimalFormatX, DecimalFormat pDecimalFormatY,
                                     String pNumberSuffixes, Integer pNumberGroupSplit) {
        mCoordinates = pCoordinates;
        mLineLabels = pLabels;
        mLineColors = pColors;
        mXAxisLabel = pXAxisLabel;
        mYAxisLabel = pYAxisLabel;
        mUseNumberAbbreviationSuffixXValue = pUseNumberAbbreviationSuffixXValue;
        mUseNumberAbbreviationSuffixYValue = pUseNumberAbbreviationSuffixYValue;
        mDecimalFormatX = pDecimalFormatX;
        mDecimalFormatY = pDecimalFormatY;
        mNumberSuffixes = pNumberSuffixes;
        mNumberGroupSplit = pNumberGroupSplit;
        mInflater = (LayoutInflater) pContext.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
    }

    @Override
    public int getCount() {
        return mCoordinates.size();
    }

    @Override
    public Object getItem(int pPosition) {
        return mCoordinates;
    }

    @Override
    public long getItemId(int pPosition) {
        return pPosition;
    }

    @Override
    public View getView(int pPosition, View pConvertView, ViewGroup pParent) {
        View v = pConvertView;
        Resources res = pParent.getResources();
        if (v == null)
            v = mInflater.inflate(R.layout.linechart_popupwindow_multiplepoints_listitem,
                                    pParent, false);

        View viewColor = v.findViewById(R.id.linechart_popupwindow_itemlinecolor);
        TextView viewLabel = (TextView) v.findViewById(R.id.linechart_popupwindow_itemlinelabel);
        TextView viewXValue = (TextView) v.findViewById(R.id.linechart_popupwindow_itemxaxisvalue);
        TextView viewYValue = (TextView) v.findViewById(R.id.linechart_popupwindow_itemyaxisvalue);

        viewColor.setBackgroundColor(mLineColors.get(pPosition));
        viewLabel.setText(mLineLabels.get(pPosition));
        if (mUseNumberAbbreviationSuffixXValue)
            viewXValue.setText(String.format(res.getString(R.string.colonspace),
                                            mXAxisLabel,
                        NumberUtilities.formatValueWithSuffix(mCoordinates.get(pPosition).getX(),
                                        mDecimalFormatX, mNumberSuffixes, mNumberGroupSplit)));
        else {
            viewXValue.setText(String.format(res.getString(R.string.colonspace),
                                mXAxisLabel,
                                mDecimalFormatX.format(mCoordinates.get(pPosition).getX())));
        }

        if (mUseNumberAbbreviationSuffixYValue)
            viewYValue.setText(String.format(res.getString(R.string.colonspace),
                                            mYAxisLabel,
                        NumberUtilities.formatValueWithSuffix(mCoordinates.get(pPosition).getY(),
                                        mDecimalFormatY, mNumberSuffixes, mNumberGroupSplit)));
        else {
            viewYValue.setText(String.format(res.getString(R.string.colonspace),
                                mYAxisLabel,
                                mDecimalFormatY.format(mCoordinates.get(pPosition).getY())));
        }

        return v;
    }
}
