package sdanderson.androidcharts.PieChart;

import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.RectF;

/**
 * Created by Shane Anderson on 10/18/2014.
 *
 */
class PieChartItem {

    public String mLabel;
    public float mValue;

    public float mStartAngle;
    public float mEndAngle;

    public float mCurrentStartAngle;
    public float mCurrentEndAngle;
    public float mSweepAngle = 0f;

    public float mMiddleAngle;

    private Paint mPieChartPaint;

    private boolean mUseAnimation = false;
    private OnFinishedAnimation mFinishedAnimationHandler;

    public PieChartItem()
    {
        mPieChartPaint = new Paint();
        mPieChartPaint.setStyle(Paint.Style.FILL);
        mPieChartPaint.setColor(Color.WHITE);
        mPieChartPaint.setAntiAlias(true);
    }

    protected void setFinishedAnimationHandler(OnFinishedAnimation pFinishedAnimationHandler) {
        mFinishedAnimationHandler = pFinishedAnimationHandler;
    }

    protected void setPieSliceColor(int pColor) {
        mPieChartPaint.setColor(pColor);
    }

    protected void draw(Canvas pCanvas, RectF pRectF, Float pPercentToDraw) {
        if (!mUseAnimation)
            mSweepAngle = mEndAngle-mStartAngle;

        pCanvas.drawArc(pRectF, mStartAngle, mSweepAngle, true, mPieChartPaint);
        if (mSweepAngle >= mEndAngle - mStartAngle && mFinishedAnimationHandler != null) {
            mFinishedAnimationHandler.onSliceFinishedAnimation();
            mFinishedAnimationHandler = null;
        }

        if ((mEndAngle-mStartAngle)*(pPercentToDraw) < mEndAngle - mStartAngle) {
            mSweepAngle = (mEndAngle-mStartAngle)*pPercentToDraw;
        } else {
            mSweepAngle = mEndAngle - mStartAngle;
        }
    }

    protected int getColor () {
        return mPieChartPaint.getColor();
    }

    protected String getLabel() {
        return mLabel;
    }

    protected float getValue() {
        return mValue;
    }

    protected void reanimate() {
        mSweepAngle = 0f;
    }

    protected interface OnFinishedAnimation {
        void onSliceFinishedAnimation();
    }

    public void setUseAnimation (boolean pUseAnimation) { mUseAnimation = pUseAnimation; }
}